# Automatically generated code: EDIT AT YOUR OWN RISK
from traits import api as traits
from traitsui import api as traitsui

from tvtk import vtk_module as vtk
from tvtk import tvtk_base
from tvtk.tvtk_base_handler import TVTKBaseHandler
from tvtk import messenger
from tvtk.tvtk_base import deref_vtk
from tvtk import array_handler
from tvtk.array_handler import deref_array
from tvtk.tvtk_classes.tvtk_helper import wrap_vtk

from tvtk.tvtk_classes.typed_array__ih_e import TypedArray_IhE


class SparseArray_IhE(TypedArray_IhE):
    """
    SparseArray - Sparse, independent coordinate storage for N-way
    arrays.
    
    Superclass: TypedArray[uint8]
    
    SparseArray is a concrete Array implementation that stores
    values using sparse independent coordinate storage.  This means that
    the array stores the complete set of coordinates and the value for
    each non-null value in the array. While this approach requires
    slightly more storage than other sparse storage schemes (such as
    Compressed-Row or Compressed-Column), it is easier and more efficient
    to work with when implementing algorithms, and  it generalizes well
    for arbitrary numbers of dimensions.
    
    In addition to the value retrieval and update methods provided by
    TypedArray, SparseArray provides methods to:
    
    Get and set a special 'null' value that will be returned when
    retrieving values for undefined coordinates.
    
    Clear the contents of the array so that every set of coordinates is
    undefined.
    
    Sort the array contents so that value coordinates can be visited in a
    specific order.
    
    Retrieve pointers to the value- and coordinate-storage memory blocks.
    
    Reserve storage for a specific number of non-null values, for
    efficiency when the number of non-null values is known in advance.
    
    Recompute the array extents so that they bound the largest set of
    non-NULL values along each dimension.
    
    Specify arbitrary array extents.
    
    Add values to the array in amortized-constant time.
    
    Validate that the array does not contain duplicate coordinates.
    
    See Also:
    
    Array, TypedArray, DenseArray
    
    Thanks:
    
    Developed by Timothy M. Shead (tshead@sandia.gov) at Sandia National
    Laboratories.
    
    """
    def __init__(self, obj=None, update=True, **traits):
        tvtk_base.TVTKBase.__init__(self, vtk.vtkSparseArray_IhE, obj, update, **traits)
    
    def get_value_n(self, *args):
        """
        V.get_value_n(int) -> int
        C++: const unsigned char &GetValueN(const SizeT n)"""
        ret = self._wrap_call(self._vtk_obj.GetValueN, *args)
        return ret

    def set_value_n(self, *args):
        """
        V.set_value_n(int, int)
        C++: void SetValueN(const SizeT n, const unsigned char &value)"""
        ret = self._wrap_call(self._vtk_obj.SetValueN, *args)
        return ret

    def get_value(self, *args):
        """
        V.get_value(int) -> int
        C++: const unsigned char &GetValue(CoordinateT i)
        V.get_value(int, int) -> int
        C++: const unsigned char &GetValue(CoordinateT i, CoordinateT j)
        V.get_value(int, int, int) -> int
        C++: const unsigned char &GetValue(CoordinateT i, CoordinateT j,
            CoordinateT k)
        V.get_value(ArrayCoordinates) -> int
        C++: const unsigned char &GetValue(
            const ArrayCoordinates &coordinates)"""
        my_args = deref_array(args, [['int'], ('int', 'int'), ('int', 'int', 'int'), ['vtkArrayCoordinates']])
        ret = self._wrap_call(self._vtk_obj.GetValue, *my_args)
        return ret

    def set_value(self, *args):
        """
        V.set_value(int, int)
        C++: void SetValue(CoordinateT i, const unsigned char &value)
        V.set_value(int, int, int)
        C++: void SetValue(CoordinateT i, CoordinateT j,
            const unsigned char &value)
        V.set_value(int, int, int, int)
        C++: void SetValue(CoordinateT i, CoordinateT j, CoordinateT k,
            const unsigned char &value)
        V.set_value(ArrayCoordinates, int)
        C++: void SetValue(const ArrayCoordinates &coordinates,
            const unsigned char &value)"""
        my_args = deref_array(args, [('int', 'int'), ('int', 'int', 'int'), ('int', 'int', 'int', 'int'), ('vtkArrayCoordinates', 'int')])
        ret = self._wrap_call(self._vtk_obj.SetValue, *my_args)
        return ret

    null_value = traits.Int(0, enter_set=True, auto_set=False, help=\
        """
        Set the value that will be returned by get_value() for NULL areas
        of the array.
        """
    )
    def _null_value_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetNullValue,
                        self.null_value)

    def add_value(self, *args):
        """
        V.add_value(int, int)
        C++: void AddValue(CoordinateT i, const unsigned char &value)
        V.add_value(int, int, int)
        C++: void AddValue(CoordinateT i, CoordinateT j,
            const unsigned char &value)
        V.add_value(int, int, int, int)
        C++: void AddValue(CoordinateT i, CoordinateT j, CoordinateT k,
            const unsigned char &value)
        V.add_value(ArrayCoordinates, int)
        C++: void AddValue(const ArrayCoordinates &coordinates,
            const unsigned char &value)
        Adds a new non-null element to the array.  Does not test to see
        if an element with matching coordinates already exists.  Useful
        for providing fast initialization of the array as long as the
        caller is prepared to guarantee that no duplicate coordinates are
        ever used.
        """
        my_args = deref_array(args, [('int', 'int'), ('int', 'int', 'int'), ('int', 'int', 'int', 'int'), ('vtkArrayCoordinates', 'int')])
        ret = self._wrap_call(self._vtk_obj.AddValue, *my_args)
        return ret

    def clear(self):
        """
        V.clear()
        C++: void Clear()
        Remove all non-null elements from the array, leaving the number
        of dimensions, the extent of each dimension, and the label for
        each dimension unchanged.
        """
        ret = self._vtk_obj.Clear()
        return ret
        

    def reserve_storage(self, *args):
        """
        V.reserve_storage(int)
        C++: void ReserveStorage(const SizeT value_count)
        Reserve storage for a specific number of values.  This is useful
        for reading external data using get_coordinate_storage() and
        get_value_storage(), when the total number of non-NULL values in
        the array can be determined in advance.  Note that after calling
        reserve_storage(), all coordinates and values will be undefined,
        so you must ensure that every set of coordinates and values is
        overwritten.  It is the caller's responsibility to ensure that
        duplicate coordinates are not inserted into the array.
        """
        ret = self._wrap_call(self._vtk_obj.ReserveStorage, *args)
        return ret

    def set_extents_from_contents(self):
        """
        V.set_extents_from_contents()
        C++: void SetExtentsFromContents()
        Update the array extents to match its contents, so that the
        extent along each dimension matches the maximum index value along
        that dimension.
        """
        ret = self._vtk_obj.SetExtentsFromContents()
        return ret
        

    def sort(self, *args):
        """
        V.sort(ArraySort)
        C++: void Sort(const ArraySort &sort)
        Sorts array values so that their coordinates appear in some
        well-defined order. The supplied ArraySort object controls
        which dimensions are sorted, and in what order, and should
        contain one-or-more sort dimensions, up to the number of
        dimensions stored in the array.
        """
        my_args = deref_array(args, [['vtkArraySort']])
        ret = self._wrap_call(self._vtk_obj.Sort, *my_args)
        return ret

    def validate(self):
        """
        V.validate() -> bool
        C++: bool Validate()
        Validate the contents of the array, returning false if there are
        any problems. Potential problems include duplicate coordinates,
        which can be introduced into the array either through add_value()
        or direct access to coordinates storage; and coordinates
        out-of-bounds given the current array extents.
        
        Note that Validate() is a heavyweight O(N log N) operation that
        is intended for temporary use during debugging.
        """
        ret = self._vtk_obj.Validate()
        return ret
        

    _updateable_traits_ = \
    (('debug', 'GetDebug'), ('dimension_label', 'GetDimensionLabel'),
    ('name', 'GetName'), ('null_value', 'GetNullValue'),
    ('reference_count', 'GetReferenceCount'), ('global_warning_display',
    'GetGlobalWarningDisplay'))
    
    _full_traitnames_list_ = \
    (['debug', 'global_warning_display', 'dimension_label', 'name',
    'null_value'])
    
    def trait_view(self, name=None, view_element=None):
        if view_element is not None or name not in (None, '', 'traits_view', 'full_traits_view', 'view'):
            return super(SparseArray_IhE, self).trait_view(name, view_element)
        if name == 'full_traits_view':
            full_traits_view = \
            traitsui.View((traitsui.Item("handler._full_traits_list",show_label=False)),
            title='Edit SparseArray_IhE properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return full_traits_view
        elif name == 'view':
            view = \
            traitsui.View(([], [], ['dimension_label', 'name', 'null_value']),
            title='Edit SparseArray_IhE properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return view
        elif name in (None, 'traits_view'):
            traits_view = \
            traitsui.View((traitsui.HGroup(traitsui.spring, "handler.view_type", show_border=True), 
            traitsui.Item("handler.info.object", editor = traitsui.InstanceEditor(view_name="handler.view"), style = "custom", show_label=False)),
            title='Edit SparseArray_IhE properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return traits_view
            

