# Automatically generated code: EDIT AT YOUR OWN RISK
from traits import api as traits
from traitsui import api as traitsui

from tvtk import vtk_module as vtk
from tvtk import tvtk_base
from tvtk.tvtk_base_handler import TVTKBaseHandler
from tvtk import messenger
from tvtk.tvtk_base import deref_vtk
from tvtk import array_handler
from tvtk.array_handler import deref_array
from tvtk.tvtk_classes.tvtk_helper import wrap_vtk

from tvtk.tvtk_classes.button_representation import ButtonRepresentation


class TexturedButtonRepresentation2D(ButtonRepresentation):
    """
    TexturedButtonRepresentation2D - defines a representation for a
    ButtonWidget
    
    Superclass: ButtonRepresentation
    
    This class implements one type of ButtonRepresentation. It changes
    the appearance of a user-provided polydata by assigning textures
    according to the current button state. It also provides highlighting
    (when hovering and selecting the button) by fiddling with the actor's
    property. Since this is a 2d version, the button is rendered in the
    overlay plane. Typically it is positioned in display coordinates, but
    it can be anchored to a world position so it will appear to move as
    the camera moves.
    
    To use this representation, always begin by specifying the number of
    button states.  Then provide a polydata (the polydata should have
    associated texture coordinates), and a list of textures cooresponding
    to the button states. Optionally, the hovering_property and
    selection_property can be adjusted to obtain the appropriate
    appearance.
    
    See Also:
    
    ButtonWidget ButtonRepresentation
    TexturedButtonRepresentation Prop3DButtonRepresentation
    
    """
    def __init__(self, obj=None, update=True, **traits):
        tvtk_base.TVTKBase.__init__(self, vtk.vtkTexturedButtonRepresentation2D, obj, update, **traits)
    
    def get_button_texture(self, *args):
        """
        V.get_button_texture(int) -> ImageData
        C++: ImageData *GetButtonTexture(int i)
        Add the ith texture corresponding to the ith button state. The
        parameter i should be 0<=i<_number_of_states.
        """
        ret = self._wrap_call(self._vtk_obj.GetButtonTexture, *args)
        return wrap_vtk(ret)

    def set_button_texture(self, *args):
        """
        V.set_button_texture(int, ImageData)
        C++: void SetButtonTexture(int i, ImageData *image)
        Add the ith texture corresponding to the ith button state. The
        parameter i should be 0<=i<_number_of_states.
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.SetButtonTexture, *my_args)
        return ret

    def _get_hovering_property(self):
        return wrap_vtk(self._vtk_obj.GetHoveringProperty())
    def _set_hovering_property(self, arg):
        old_val = self._get_hovering_property()
        self._wrap_call(self._vtk_obj.SetHoveringProperty,
                        deref_vtk(arg))
        self.trait_property_changed('hovering_property', old_val, arg)
    hovering_property = traits.Property(_get_hovering_property, _set_hovering_property, help=\
        """
        Specify the property to use when the hovering over the button.
        """
    )

    def _get_selecting_property(self):
        return wrap_vtk(self._vtk_obj.GetSelectingProperty())
    def _set_selecting_property(self, arg):
        old_val = self._get_selecting_property()
        self._wrap_call(self._vtk_obj.SetSelectingProperty,
                        deref_vtk(arg))
        self.trait_property_changed('selecting_property', old_val, arg)
    selecting_property = traits.Property(_get_selecting_property, _set_selecting_property, help=\
        """
        Specify the property to use when selecting the button.
        """
    )

    def _get_property(self):
        return wrap_vtk(self._vtk_obj.GetProperty())
    def _set_property(self, arg):
        old_val = self._get_property()
        self._wrap_call(self._vtk_obj.SetProperty,
                        deref_vtk(arg))
        self.trait_property_changed('property', old_val, arg)
    property = traits.Property(_get_property, _set_property, help=\
        """
        Specify the property to use when the button is to appear "normal"
        i.e., the mouse pointer is not hovering or selecting the button.
        """
    )

    def _get_balloon(self):
        return wrap_vtk(self._vtk_obj.GetBalloon())
    balloon = traits.Property(_get_balloon, help=\
        """
        Grab the underlying BalloonRepresentation used to position and
        display the button texture.
        """
    )

    def place_widget(self, *args):
        """
        V.place_widget([float, float, float, float, float, float])
        C++: virtual void PlaceWidget(double bounds[6])
        V.place_widget([float, float, float], [int, int])
        C++: virtual void PlaceWidget(double anchor[3], int size[2])
        Conventional place_widget() method to satisfy the
        WidgetRepresentation API. In this version, bounds[6] specifies
        a rectangle in *display* coordinates in which to place the
        button. The values for bounds[4] and bounds[5] can be set to
        zero. Note that place_widget() is typically called at the end of
        configuring the button representation.
        """
        ret = self._wrap_call(self._vtk_obj.PlaceWidget, *args)
        return ret

    _updateable_traits_ = \
    (('allocated_render_time', 'GetAllocatedRenderTime'), ('handle_size',
    'GetHandleSize'), ('estimated_render_time', 'GetEstimatedRenderTime'),
    ('debug', 'GetDebug'), ('dragable', 'GetDragable'), ('visibility',
    'GetVisibility'), ('reference_count', 'GetReferenceCount'), ('state',
    'GetState'), ('need_to_render', 'GetNeedToRender'),
    ('render_time_multiplier', 'GetRenderTimeMultiplier'),
    ('place_factor', 'GetPlaceFactor'), ('pickable', 'GetPickable'),
    ('use_bounds', 'GetUseBounds'), ('global_warning_display',
    'GetGlobalWarningDisplay'))
    
    _full_traitnames_list_ = \
    (['debug', 'dragable', 'global_warning_display', 'need_to_render',
    'pickable', 'use_bounds', 'visibility', 'allocated_render_time',
    'estimated_render_time', 'handle_size', 'place_factor',
    'render_time_multiplier', 'state'])
    
    def trait_view(self, name=None, view_element=None):
        if view_element is not None or name not in (None, '', 'traits_view', 'full_traits_view', 'view'):
            return super(TexturedButtonRepresentation2D, self).trait_view(name, view_element)
        if name == 'full_traits_view':
            full_traits_view = \
            traitsui.View((traitsui.Item("handler._full_traits_list",show_label=False)),
            title='Edit TexturedButtonRepresentation2D properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return full_traits_view
        elif name == 'view':
            view = \
            traitsui.View((['need_to_render', 'use_bounds', 'visibility'], [],
            ['allocated_render_time', 'estimated_render_time', 'handle_size',
            'place_factor', 'render_time_multiplier', 'state']),
            title='Edit TexturedButtonRepresentation2D properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return view
        elif name in (None, 'traits_view'):
            traits_view = \
            traitsui.View((traitsui.HGroup(traitsui.spring, "handler.view_type", show_border=True), 
            traitsui.Item("handler.info.object", editor = traitsui.InstanceEditor(view_name="handler.view"), style = "custom", show_label=False)),
            title='Edit TexturedButtonRepresentation2D properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return traits_view
            

