# Automatically generated code: EDIT AT YOUR OWN RISK
from traits import api as traits
from traitsui import api as traitsui

from tvtk import vtk_module as vtk
from tvtk import tvtk_base
from tvtk.tvtk_base_handler import TVTKBaseHandler
from tvtk import messenger
from tvtk.tvtk_base import deref_vtk
from tvtk import array_handler
from tvtk.array_handler import deref_array
from tvtk.tvtk_classes.tvtk_helper import wrap_vtk

from tvtk.tvtk_classes.threaded_image_algorithm import ThreadedImageAlgorithm


class VolumeRayCastSpaceLeapingImageFilter(ThreadedImageAlgorithm):
    """
    VolumeRayCastSpaceLeapingImageFilter - Builds the space leaping
    data structure.
    
    Superclass: ThreadedImageAlgorithm
    
    This is an optimized multi-threaded imaging filter that builds the
    space leaping datastructure, used by
    FixedPointVolumeRayCastMapper. Empty space leaping is used to skip
    large empty regions in the scalar opacity and/or the gradient opacity
    transfer functions. Depending on the various options set by
    FixedPointVolumeRayCastMapper, the class will internally invoke
    one of the many optmized routines to compute the min/max/gradient-max
    values within a fixed block size, trying to compute everything in a
    single multi-threaded pass through the data
    
    The block size may be changed at compile time. Its ifdef'ed to 4 in
    the CXX file.
    
    """
    def __init__(self, obj=None, update=True, **traits):
        tvtk_base.TVTKBase.__init__(self, vtk.vtkVolumeRayCastSpaceLeapingImageFilter, obj, update, **traits)
    
    compute_gradient_opacity = tvtk_base.false_bool_trait(help=\
        """
        Compute gradient opacity ?
        """
    )
    def _compute_gradient_opacity_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetComputeGradientOpacity,
                        self.compute_gradient_opacity_)

    compute_min_max = tvtk_base.false_bool_trait(help=\
        """
        Compute the min max structure ?.
        """
    )
    def _compute_min_max_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetComputeMinMax,
                        self.compute_min_max_)

    update_gradient_opacity_flags = tvtk_base.false_bool_trait(help=\
        """
        Update the gradient opacity flags. (The scalar opacity flags are
        always updated upon execution of this filter.)
        """
    )
    def _update_gradient_opacity_flags_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetUpdateGradientOpacityFlags,
                        self.update_gradient_opacity_flags_)

    def _get_current_scalars(self):
        return wrap_vtk(self._vtk_obj.GetCurrentScalars())
    def _set_current_scalars(self, arg):
        old_val = self._get_current_scalars()
        my_arg = deref_array([arg], [['vtkDataArray']])
        self._wrap_call(self._vtk_obj.SetCurrentScalars,
                        my_arg[0])
        self.trait_property_changed('current_scalars', old_val, arg)
    current_scalars = traits.Property(_get_current_scalars, _set_current_scalars, help=\
        """
        Set the scalars.
        """
    )

    table_scale = traits.Array(shape=(4,), value=(1.0, 1.0, 1.0, 1.0), dtype=float, enter_set=True, auto_set=False, cols=3, help=\
        """
        
        """
    )
    def _table_scale_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTableScale,
                        self.table_scale)

    table_shift = traits.Array(shape=(4,), value=(0.0, 0.0, 0.0, 0.0), dtype=float, enter_set=True, auto_set=False, cols=3, help=\
        """
        
        """
    )
    def _table_shift_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTableShift,
                        self.table_shift)

    independent_components = traits.Int(1, enter_set=True, auto_set=False, help=\
        """
        Do we use independent components, or dependent components ?
        """
    )
    def _independent_components_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetIndependentComponents,
                        self.independent_components)

    table_size = traits.Array(shape=(4,), value=(0, 0, 0, 0), dtype=int, enter_set=True, auto_set=False, cols=3, help=\
        """
        
        """
    )
    def _table_size_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTableSize,
                        self.table_size)

    def _get_last_min_max_build_time(self):
        return self._vtk_obj.GetLastMinMaxBuildTime()
    last_min_max_build_time = traits.Property(_get_last_min_max_build_time, help=\
        """
        Get the last execution time. This is updated every time the
        scalars or the gradient opacity values are computed
        """
    )

    def _get_last_min_max_flag_time(self):
        return self._vtk_obj.GetLastMinMaxFlagTime()
    last_min_max_flag_time = traits.Property(_get_last_min_max_flag_time, help=\
        """
        Get the last execution time. This is updated every time the flags
        bits are re-computed.
        """
    )

    def _get_number_of_independent_components(self):
        return self._vtk_obj.GetNumberOfIndependentComponents()
    number_of_independent_components = traits.Property(_get_number_of_independent_components, help=\
        """
        Get the number of independent components for which we need to
        keep track of min/max
        """
    )

    def compute_input_extents_for_output(self, *args):
        """
        V.compute_input_extents_for_output([int, int, int, int, int, int],
            [int, int, int], [int, int, int, int, int, int], ImageData)
        C++: static void ComputeInputExtentsForOutput(int inExt[6],
            int inDim[3], int outExt[6], ImageData *inData)
        Compute the extents and dimensions of the input that's required
        to generate an output min-max structure given by out_ext. INTERNAL
        - Do not use
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.ComputeInputExtentsForOutput, *my_args)
        return ret

    def compute_offset(self, *args):
        """
        V.compute_offset((int, int, int, int, int, int), (int, int, int,
            int, int, int), int) -> int
        C++: IdType ComputeOffset(const int ext[6],
            const int wholeExt[6], int nComponents)
        INTERNAL - Do not use Compute the offset within an image of whole
        extents whole_ext, to access the data starting at extents ext.
        """
        ret = self._wrap_call(self._vtk_obj.ComputeOffset, *args)
        return ret

    def set_cache(self, *args):
        """
        V.set_cache(ImageData)
        C++: virtual void SetCache(ImageData *imageCache)
        INTERNAL - Do not use Set the last cached min-max volume, as used
        by FixedPointVolumeRayCastMapper.
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.SetCache, *my_args)
        return ret

    _updateable_traits_ = \
    (('table_shift', 'GetTableShift'), ('global_warning_display',
    'GetGlobalWarningDisplay'), ('compute_gradient_opacity',
    'GetComputeGradientOpacity'), ('table_scale', 'GetTableScale'),
    ('independent_components', 'GetIndependentComponents'),
    ('progress_text', 'GetProgressText'),
    ('update_gradient_opacity_flags', 'GetUpdateGradientOpacityFlags'),
    ('compute_min_max', 'GetComputeMinMax'), ('debug', 'GetDebug'),
    ('abort_execute', 'GetAbortExecute'), ('number_of_threads',
    'GetNumberOfThreads'), ('release_data_flag', 'GetReleaseDataFlag'),
    ('reference_count', 'GetReferenceCount'), ('progress', 'GetProgress'),
    ('table_size', 'GetTableSize'))
    
    _full_traitnames_list_ = \
    (['abort_execute', 'compute_gradient_opacity', 'compute_min_max',
    'debug', 'global_warning_display', 'release_data_flag',
    'update_gradient_opacity_flags', 'independent_components',
    'number_of_threads', 'progress_text', 'table_scale', 'table_shift',
    'table_size'])
    
    def trait_view(self, name=None, view_element=None):
        if view_element is not None or name not in (None, '', 'traits_view', 'full_traits_view', 'view'):
            return super(VolumeRayCastSpaceLeapingImageFilter, self).trait_view(name, view_element)
        if name == 'full_traits_view':
            full_traits_view = \
            traitsui.View((traitsui.Item("handler._full_traits_list",show_label=False)),
            title='Edit VolumeRayCastSpaceLeapingImageFilter properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return full_traits_view
        elif name == 'view':
            view = \
            traitsui.View((['compute_gradient_opacity', 'compute_min_max',
            'update_gradient_opacity_flags'], [], ['independent_components',
            'number_of_threads', 'table_scale', 'table_shift', 'table_size']),
            title='Edit VolumeRayCastSpaceLeapingImageFilter properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return view
        elif name in (None, 'traits_view'):
            traits_view = \
            traitsui.View((traitsui.HGroup(traitsui.spring, "handler.view_type", show_border=True), 
            traitsui.Item("handler.info.object", editor = traitsui.InstanceEditor(view_name="handler.view"), style = "custom", show_label=False)),
            title='Edit VolumeRayCastSpaceLeapingImageFilter properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return traits_view
            

